.. include:: ../README.rst

API Documentation
=================

Loudspeaker Arrays
------------------

.. automodule:: sfs.array
   :members:
   :undoc-members:

Tapering
--------

.. automodule:: sfs.tapering
   :members:
   :undoc-members:

Monochromatic Sources
---------------------

.. automodule:: sfs.mono.source
   :members:
   :undoc-members:

Monochromatic Driving Functions
-------------------------------

.. automodule:: sfs.mono.drivingfunction
   :members:
   :undoc-members:

Monochromatic Sound Fields
--------------------------

.. automodule:: sfs.mono.synthesized
   :members:
   :undoc-members:

Plotting
--------

.. automodule:: sfs.plot
   :members:
   :undoc-members:

Utilities
---------

.. automodule:: sfs.util
   :members:
   :undoc-members:

Indices
=======

* :ref:`genindex`
* :ref:`modindex`
